@@ -198,6 +198,18 @@ func main() {
 		startNodeMonitor()
 	}
 
+	if config.Config.PurgeNodeStatusAfter != "" {
+		startNodeStatusPurge()
+	}
+
+	if config.Config.PurgeReportsAfter != "" {
+		startReportPurge()
+	}
+
+	if config.Config.PurgeSandboxesDur != 0 {
+		startSandboxPurge()
+	}
+
 	/* Create default clients and users. Currently chef-validator,
 	 * chef-webui, and admin. */
 	createDefaultActors()
@@ -793,6 +805,55 @@ func startNodeMonitor() {
 	return
 }
 
+func startReportPurge() {
+	go func() {
+		// purge reports after 2 hours, I guess.
+		ticker := time.NewTicker(2 * time.Hour)
+		for _ = range ticker.C {
+			del, err := report.DeleteByAge(config.Config.PurgeReportsDur)
+			if err != nil {
+				logger.Errorf("Purging reports had an error: %s", err.Error())
+			} else {
+				logger.Debugf("Purged %d reports", del)
+			}
+		}
+	}()
+}
+
+func startSandboxPurge() {
+	go func() {
+		// check for sandboxes to purge every hour
+		ticker := time.NewTicker(time.Hour)
+		for _ = range ticker.C {
+			del, err := sandbox.Purge(config.Config.PurgeSandboxesDur)
+			if err != nil {
+				logger.Errorf("Purging sandboxes (somehow) had an error: %s", err.Error())
+			} else {
+				logger.Debugf("Purged %d sandboxes", del)
+			}
+		}
+	}()
+}
+
+func startNodeStatusPurge() {
+	// don't do it if there aren't going to be node statuses to purge
+	if !config.Config.UseSerf || config.Config.PurgeNodeStatusDur == 0 {
+		return
+	}
+	go func() {
+		// check every 2 hours for statuses to purge
+		ticker := time.NewTicker(2 * time.Hour)
+		for _ = range ticker.C {
+			del, err := node.DeleteNodeStatusesByAge(config.Config.PurgeNodeStatusDur)
+			if err != nil {
+				logger.Errorf("Purging node statuses had an error: %s", err.Error())
+			} else {
+				logger.Debugf("Purged %d node statuses", del)
+			}
+		}
+	}()
+}
+
 func initGeneralStatsd(metricsBackend met.Backend) {
 	if !config.Config.UseStatsd {
 		return
